pub enum CompareOp {
Show 13 variants
Equal,
NotEqual,
In,
NotIn,
Exists,
NotExists,
StartsWith,
EndsWith,
Contains,
GreaterThan,
GreaterThanOrEqual,
LessThan,
LessThanOrEqual,
}Expand description
Comparison operators for leaf node filters.
These operators are used to compare tag values against filter values. All string representations are lowercase for consistency with the protocol.
Variants
Equal
Equality: tag_value == filter_value
NotEqual
Inequality: tag_value != filter_value
In
Set membership: tag_value in filter_values
NotIn
Set non-membership: tag_value not in filter_values
Exists
Key exists in tags
NotExists
Key does not exist in tags
StartsWith
String starts with: tag_value.starts_with(filter_value)
EndsWith
String ends with: tag_value.ends_with(filter_value)
Contains
String contains: tag_value.contains(filter_value)
GreaterThan
Numeric greater than: tag_value > filter_value
GreaterThanOrEqual
Numeric greater than or equal: tag_value >= filter_value
LessThan
Numeric less than: tag_value < filter_value
LessThanOrEqual
Numeric less than or equal: tag_value <= filter_value
Implementations